/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.location.tag.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.yiring.app.domain.location.LocationTag;
import com.yiring.app.domain.location.LocationTagRepository;
import com.yiring.app.param.location.tag.LocationTagTypeFindParam;
import com.yiring.app.service.location.tag.LocationTagTypeService;
import com.yiring.app.vo.location.tag.LocationTagTypeVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 部门信息控制器
 *
 * @author LJ-2204
 * @date 2022/4/27
 */

@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class LocationTagTypeServiceImpl implements LocationTagTypeService {

    @Resource
    LocationTagRepository locationTagRepository;

    @Override
    public Result<PageVo<LocationTagTypeVo>> findLocationTagType(
        LocationTagTypeFindParam locationTagTypeFindParam,
        PageParam pageParam
    ) {
        Specification<LocationTag> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (StrUtil.isNotEmpty(locationTagTypeFindParam.getCode())) {
                predicates.add(
                    cb.like(root.get(LocationTag.Fields.code), "%" + locationTagTypeFindParam.getCode() + "%")
                );
            }

            if (ObjectUtil.isNotEmpty(locationTagTypeFindParam.getCategory())) {
                predicates.add(cb.equal(root.get(LocationTag.Fields.category), locationTagTypeFindParam.getCategory()));
            }

            Order order = cb.desc(root.get(LocationTag.Fields.createTime));

            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        List<LocationTag> locationTags = locationTagRepository.findAll(specification);
        List<LocationTagTypeVo> locationTagTypeVos = locationTags
            .stream()
            .map(LocationTagTypeVo::transform)
            .collect(Collectors.toList());
        PageVo<LocationTagTypeVo> pageVo = PageVo.build(locationTagTypeVos, locationTagTypeVos.size());
        return Result.ok(pageVo);
    }
}
