/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.fence;

import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.domain.location.LocationFence;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 11:07
 */
@ApiModel("围栏信息VO")
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class LocationFenceVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 3616144084051520412L;

    @ApiModelProperty(value = "围栏名称")
    private String name;

    @ApiModelProperty(value = "地图名称")
    private String mapName;

    @ApiModelProperty(value = "摄像头名称")
    private String videoName;

    @ApiModelProperty(value = "围栏类别")
    private String fenceType;

    @ApiModelProperty(value = "滞留时间(秒)")
    private Integer residenceTime;

    @ApiModelProperty(value = "消抖时间(秒)")
    private Integer threshold;

    @ApiModelProperty(value = "是否启用")
    private Boolean enable;

    public static LocationFenceVo transform(LocationFence locationFence) {
        return LocationFenceVo
            .builder()
            .name(locationFence.getName())
            .mapName(locationFence.getMapName())
            .videoName(locationFence.getVideo().getVideoName())
            .fenceType(FenceTypeEnum.getByCode(locationFence.getFenceType()))
            .residenceTime(locationFence.getResidenceTime())
            .threshold(locationFence.getThreshold())
            .enable(locationFence.getEnable())
            .build();
    }

    public static List<LocationFenceVo> transforms(List<LocationFence> locationFences) {
        return locationFences.stream().map(LocationFenceVo::transform).collect(Collectors.toList());
    }
}
