/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.location.fence;

import com.yiring.app.param.location.fence.LocationFenceAddParam;
import com.yiring.app.param.location.fence.LocationFenceConditionParam;
import com.yiring.app.param.location.fence.LocationFenceModifyParam;
import com.yiring.app.service.location.fence.LocationFenceService;
import com.yiring.app.vo.location.fence.LocationFenceVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 11:50
 */
@RestController
@Api(tags = "LocationFenceController(围栏信息)")
@Validated
@Slf4j
@RequestMapping("location/fence")
public class LocationFenceController {

    @Resource
    private LocationFenceService locationFenceService;

    @ApiOperation("添加围栏信息")
    @PostMapping("/addLocationFence")
    public Result<String> addLocationFence(@Valid @RequestBody LocationFenceAddParam param) {
        return locationFenceService.addLocationFence(param);
    }

    @ApiOperation("修改围栏信息")
    @PostMapping("/modifyLocationFence")
    public Result<String> modifyLocationFence(@Valid @RequestBody LocationFenceModifyParam param) {
        return locationFenceService.modifyLocationFence(param);
    }

    @ApiOperation("删除围栏信息")
    @PostMapping("/removeLocationFence")
    public Result<String> removeLocationFence(@Valid IdParam param) {
        return locationFenceService.removeLocationFence(param);
    }

    @ApiOperation("根据条件分页查询围栏信息")
    @PostMapping("/LocationFenceVo")
    public Result<PageVo<LocationFenceVo>> findList(
        @Valid LocationFenceConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        return locationFenceService.findList(conditionParam, pageParam);
    }
}
